<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_content
 *
 * @copyright   Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;


$tplparams = JFactory::getApplication()->getTemplate(true)->params;
$category  = JCategories::getInstance('Content')->get($this->item->catid);
$catparam  = MagzHelper::getParam($category);

$exinfo    = MagzHelper::getEx($this->item);
$iclass    = array('items', strtolower($this->item->category_alias), $exinfo['type']);

$params    = $this->item->params;
$images    = json_decode($this->item->images);
$canEdit   = $this->item->params->get('access-edit');

$link      = false;

if (!empty($images->image_intro)) {
	$intro_src   = $images->image_intro;
	$intro_title = !empty($images->image_intro_caption) ? $images->image_intro_caption : $this->item->title;
	$intro_alt   = !empty($images->image_intro_alt) ? $images->image_intro_alt : $this->item->title;
} else {
	$isrc        = MagzHelper::image($this->item, $exinfo['type']);
	$intro_src   = !empty($isrc['src']) ? $isrc['src'] : '';
	$intro_title = $intro_alt = $this->item->title;
}

if ($this->item->state == 0) {
	$iclass[] = 'system-unpublished';
}
if (empty($intro_src)) {
	$iclass[] = 'no-image';
}

if ($params->get('link_titles') && $params->get('access-view')) {
	$link = JRoute::_(ContentHelperRoute::getArticleRoute($this->item->slug, $this->item->catid));
}
?>
<div class="<?php echo implode(' ', array_unique($iclass)) ?>">
	<!-- Article -->
	<article class="clearfix">
		<div class="item-wrap">

			<div class="header-article clearfix">
				<div class="item-image images-content clearfix">
					<?php if (!empty($intro_src)): ?>
						<?php if ($link): ?>
							<a class="article-link" href="<?php echo $link; ?>" title="<?php echo $this->escape($this->item->title); ?>">
						<?php endif; ?>
							<?php echo MagzHelper::icon($exinfo['type']) ?>
							<img title="<?php echo htmlspecialchars($intro_title); ?>"
								 src="<?php echo htmlspecialchars($intro_src); ?>"
								 alt="<?php echo htmlspecialchars($intro_alt); ?>"/>
						<?php if ($link): ?>
							</a>
						<?php endif; ?>
					<?php endif; ?>

					<?php if ($params->get('show_category')) : ?>
						<div class="category-name <?php echo $catparam->get('tpl_cat_color', '') ?>">
							<?php $title = $this->escape($this->item->category_title);
							$url = '<a href="' . JRoute::_(ContentHelperRoute::getCategoryRoute($this->item->catslug)) . '">' . $title . '</a>';?>
							<?php if ($params->get('link_category') AND $this->item->catslug) : ?>
								<?php echo '<span class="name">', JText::sprintf('COM_CONTENT_CATEGORY', '</span><span>' . $url . '</span>'); ?>
							<?php else : ?>
								<?php echo '<span>', JText::sprintf('COM_CONTENT_CATEGORY', '</span><span>' . $title . '</span>'); ?>
							<?php endif; ?>
						</div>
					<?php endif; ?>
				</div>

				<!-- Aside -->
				<?php if (($params->get('show_author'))
					or ($params->get('show_create_date'))
					or ($params->get('show_publish_date'))
					or ($params->get('show_parent_category'))
					or ($params->get('show_print_icon'))
					or ($params->get('show_email_icon'))
					or ($canEdit)
				) : ?>
					<aside class="article-aside clearfix">

						<?php if (($params->get('show_author'))
							or ($params->get('show_create_date'))
							or ($params->get('show_publish_date'))
							or ($params->get('show_parent_category'))
						) : ?>
							<dl class="article-info">
								<dt class="article-info-term"><?php echo JText::_('COM_CONTENT_ARTICLE_INFO'); ?></dt>

								<?php if ($params->get('show_author') && !empty($this->item->author)) : ?>
									<dd class="createdby first-child">
										<?php $author = $this->item->author; ?>
										<?php $author = ($this->item->created_by_alias ? $this->item->created_by_alias : $author); ?>
										<?php if (!empty($this->item->contactid) && $params->get('link_author') == true): ?>
											<?php $addparams = $tplparams->get('tpl_userpage_mid') ? '&Itemid=' . $tplparams->get('tpl_userpage_mid') : ''; ?>
											<?php echo '<span class="name">', JText::sprintf('COM_CONTENT_WRITTEN_BY',
												'</span><span>' . JHtml::_('link', JRoute::_('index.php?option=com_contact&view=contact' . $addparams . '&id=' . $this->item->contactid), $author) . '</span>'); ?>
										<?php else : ?>
											<?php echo '<span class="name">', JText::sprintf('COM_CONTENT_WRITTEN_BY', '</span><span>' . $author . '</span>'); ?>
										<?php endif; ?>
									</dd>
								<?php endif; ?>

								<?php if ($params->get('show_publish_date')) : ?>
									<dd class="published">
										<span><?php echo MagzHelper::relTime($this->item->publish_up); ?></span>
									</dd>
								<?php endif; ?>

								<?php if ($params->get('show_create_date')) : ?>
									<dd class="create">
										<span><?php echo MagzHelper::relTime($this->item->created); ?></span>
									</dd>
								<?php endif; ?>

								<?php if ($params->get('show_parent_category') && $this->item->parent_id != 1) : ?>
									<dd class="parent-category-name">
										<?php $title = $this->escape($this->item->parent_title);
										$url = '<a href="' . JRoute::_(ContentHelperRoute::getCategoryRoute($this->item->parent_slug)) . '">' . $title . '</a>'; ?>
										<?php if ($params->get('link_parent_category') AND $this->item->parent_slug) : ?>
											<?php echo JText::sprintf('COM_CONTENT_PARENT', '<span>' . $url . '</span>'); ?>
										<?php else : ?>
											<?php echo JText::sprintf('COM_CONTENT_PARENT', '<span>' . $title . '</span>'); ?>
										<?php endif; ?>
									</dd>
								<?php endif; ?>

							</dl>
						<?php endif; ?>

						<?php if ($params->get('show_print_icon') || $params->get('show_email_icon') || $canEdit) : ?>
							<div class="menu-edit pull-right">
								<ul class="clearfix">
									<?php if ($params->get('show_print_icon')) : ?>
										<li class="print-icon"> <?php echo JHtml::_('icon.print_popup', $this->item, $params); ?> </li>
									<?php endif; ?>
									<?php if ($params->get('show_email_icon')) : ?>
										<li class="email-icon"> <?php echo JHtml::_('icon.email', $this->item, $params); ?> </li>
									<?php endif; ?>
									<?php if ($canEdit) : ?>
										<li class="edit-icon"> <?php echo JHtml::_('icon.edit', $this->item, $params); ?> </li>
									<?php endif; ?>
								</ul>
							</div>
						<?php endif; ?>

					</aside>
				<?php endif; ?>
				<!-- //Aside -->

				<?php if ($params->get('show_title')) : ?>
					<header class="article-header clearfix">
						<h2 class="article-title">
							<?php if ($link) : ?>
								<a class="article-link"
								   href="<?php echo $link; ?>"> <?php echo $this->escape($this->item->title); ?></a>
							<?php else : ?>
								<?php echo $this->escape($this->item->title); ?>
							<?php endif; ?>
						</h2>
					</header>
				<?php endif; ?>
			</div>

			<div class="info-article">

				<?php if (!$params->get('show_intro')) : ?>
					<?php echo $this->item->event->afterDisplayTitle; ?>
				<?php endif; ?>

				<?php echo $this->item->event->beforeDisplayContent; ?>

				<section class="article-intro clearfix">
					<?php $introtext = MagzHelper::sanitize($this->item); ?>
					<?php echo JHtml::_('string.truncate', $introtext, $tplparams->get('tpl_introtext_limit', 200)); ?>
				</section>

				<?php if ($params->get('show_tags', 1) && !empty($this->item->tags)) : ?>
					<?php $this->item->tagLayout = new JLayoutFile('joomla.content.tags'); ?>
					<?php echo $this->item->tagLayout->render($this->item->tags->itemTags); ?>
				<?php endif; ?>

				<section class="comment-count clearfix">

					<?php if (($params->get('show_modify_date')) or ($params->get('show_hits'))) : ?>
						<footer class="article-footer clearfix">
							<dl class="article-info pull-left">
								<dt class="article-info-term"><?php echo JText::_('TPL_ARTICLE_FOOTER_INFO'); ?></dt>

								<?php if ($params->get('show_modify_date')) : ?>
									<dd class="modified"><?php echo JText::sprintf('COM_CONTENT_LAST_UPDATED', '<span>' . JHtml::_('date', $this->item->modified, JText::_('DATE_FORMAT_LC3')) . '</span>'); ?> </dd>
								<?php endif; ?>
								<?php if ($params->get('show_hits')) : ?>
									<dd class="hits"><?php echo JText::sprintf('COM_CONTENT_ARTICLE_HITS', '<span>' . $this->item->hits . '</span>'); ?> </dd>
								<?php endif; ?>
							</dl>
						</footer>
					<?php endif; ?>

					<!-- read more -->
					<?php if ($params->get('show_readmore') && $this->item->readmore) :
						if ($params->get('access-view')) :
							$link = JRoute::_(ContentHelperRoute::getArticleRoute($this->item->slug, $this->item->catid)); else :
							$menu = JFactory::getApplication()->getMenu();
							$active = $menu->getActive();
							$itemId = $active->id;
							$link1 = JRoute::_('index.php?option=com_users&view=login&Itemid=' . $itemId);
							$returnURL = JRoute::_(ContentHelperRoute::getArticleRoute($this->item->slug, $this->item->catid));
							$link = new JURI($link1);
							$link->setVar('return', base64_encode($returnURL));
						endif;
						?>
						
						<a class="readmore" href="<?php echo $link; ?>">
							<span>
								<?php if (!$params->get('access-view')) :
									echo JText::_('COM_CONTENT_REGISTER_TO_READ_MORE'); elseif ($readmore = $this->item->alternative_readmore) :
									echo $readmore;
									if ($params->get('show_readmore_title', 0) != 0) :
										echo JHtml::_('string.truncate', ($this->item->title), $params->get('readmore_limit'));
									endif; elseif ($params->get('show_readmore_title', 0) == 0) :
									echo JText::sprintf('COM_CONTENT_READ_MORE_TITLE'); else :
									echo JText::_('COM_CONTENT_READ_MORE');
									echo JHtml::_('string.truncate', ($this->item->title), $params->get('readmore_limit'));
								endif; ?>
							</span>
						</a>
					
					<?php endif; ?>

					<!-- Comment count -->
					<?php echo $this->item->event->afterDisplayContent; ?>
					<!-- Comment count -->

					<!-- AddThis Button BEGIN -->
					<?php if($tplparams->get('tpl_addthis_share', 1)) : ?>
					<a class="addthis_button_compact" addthis:url="<?php echo JUri::getInstance()->toString(array('scheme', 'host', 'port')) . $link ?>" addthis:title="<?php echo htmlspecialchars($intro_title); ?>"> <?php echo JText::_('TPL_TEXT_SHARE') ?> <i class="icon-share"></i></a> 
					<?php endif ?>
					<!-- AddThis Button END -->
				</section>
			</div>
		</div>
	</article>
	<!-- //Article -->
</div>
